@@ -51,9 +51,9 @@ QStringList PackageKitResource::allPackageNames() const
 QString PackageKitResource::availablePackageId() const
 {
     // First we check if it's upgradeable and use this version to display
-    const QString pkgid = backend()->upgradeablePackageId(this);
-    if (!pkgid.isEmpty())
-        return pkgid;
+    const QSet<QString> pkgids = backend()->upgradeablePackageId(this);
+    if (!pkgids.isEmpty())
+        return *pkgids.constBegin();
 
     const auto it = m_packages.constFind(PackageKit::Transaction::InfoAvailable);
     if (it != m_packages.constEnd())
@@ -115,7 +115,7 @@ QString PackageKitResource::installedVersion() const
     return PackageKit::Daemon::packageVersion(installedPackageId());
 }
 
-int PackageKitResource::size()
+quint64 PackageKitResource::size()
 {
     fetchDetails();
     return m_details.size();
@@ -200,6 +200,8 @@ void PackageKitResource::setDetails(const PackageKit::Details &details)
     if (m_details != details) {
         const auto oldState = state();
         const auto oldSize = m_details.size();
+        const auto oldLicense = m_details.license();
+        const auto oldDescription = m_details.description();
         m_details = details;
 
         if (oldState != state())
@@ -211,6 +213,14 @@ void PackageKitResource::setDetails(const PackageKit::Details &details)
         if (oldSize != uint(size())) {
             Q_EMIT sizeChanged();
         }
+
+        if (oldLicense != m_details.license()) {
+            Q_EMIT licensesChanged();
+        }
+
+        if (oldDescription != m_details.description()) {
+            Q_EMIT longDescriptionChanged();
+        }
     }
 }
 
